@@ -131,7 +131,10 @@ sub process {
     my $imagere = $self->image_re;
     $self->reset_toc_stack;
     # loop over the parsed elements
-    foreach my $el ($self->document->document) {
+    foreach my $el ($self->document->elements) {
+        if ($el->type eq 'null') {
+            next;
+        }
         if ($el->type eq 'startblock') {
             die "startblock with string passed!: " . $el->string if $el->string;
             push @pieces, $self->blkstring(start => $el->block);
